pub enum DirCompareError {
WalkDir(Error),
MissingEntry(OsString),
EntryTypeMismatch {
lhs: DirEntry,
rhs: DirEntry,
},
ContentsDiffer(String),
Io(Error),
}Expand description
Errors which may be returned from directory_compare.
Variants
WalkDir(Error)
An error occurred when walking over either of the input directories.
MissingEntry(OsString)
An entry, requested as part of the expected entry set, was not present in one of the directories.
EntryTypeMismatch
The type of an entry differed (e.g., “file” vs “directory”) for a compared path.
ContentsDiffer(String)
The contents of a file differ between the compared paths.
Io(Error)
A generic I/O error occurred while accessing the filesystem.